/*
 * This program is Copyright 1998 by Henry Cohen commercial rights are reserved.
 * The program is provided as is with no warranties of any sort including 
 * fitness for any purpose.  In no case will the author be held liable for
 * damages related to the use of this program.

 * The author hereby grants rights to use, copy, modify and create derived
 * products for individual, non-commercial purposes provided a copy of this
 * notice is included.  Any commercial use requires the written approval of 
 * the author.
 * Henry Cohen 1998.
 */

package jdic;
import java.io.*;

class GeneralDictionary extends Dictionary{

    GeneralDictionary (File dictFile, boolean makeIndex, String encoding) 
	 throws BadIndexException, IOException, FileNotFoundException, 
	     SecurityException, UnsupportedEncodingException, EOFException {

		 super(dictFile, makeIndex, encoding);
    }
    /**
     * method kstrcmp returns -, 0 or + as dict1[i1] is < = or > than dict2[i2].
     * This version folds katakana and hiragana.
     */
    int kstrcmp (char[] dict1, int ix1,char[] dict2, int ix2, int n){
	char c1,t1,c2,t2;
	int result = 0;
	
scan:	
	do {
	    try {
		c1 = dict1[ix1++];
		c2 = dict2[ix2++];
	    } catch (ArrayIndexOutOfBoundsException e) {
		return result;
	    }
	    
	    switch (Character.getType(c1)){
	    case Character.UPPERCASE_LETTER: 
		c1 = Character.toLowerCase(c1);
		break;
	    case Character.OTHER_LETTER:
		if (MojiBunkai.isHiragana(c1)){
		    c1 = MojiBunkai.toKatakana(c1);
		} else {
		}
		break;
	    case Character.LOWERCASE_LETTER:
	    case Character.DECIMAL_DIGIT_NUMBER:
		break;
	    case Character.MODIFIER_LETTER:
		if (c1 == '\u309d'){
		    c1 = '\u30fd';
		    break;
		} 
		if (c1 == '\u309e'){
		    c1 = '\u30fe';
		    break;
		}
		break;
	    case Character.LETTER_NUMBER:
		if (c1 == '\u3007') {
		    c1 = '0';
		    break;
		}
	    default:
		break ;
	    }
	    switch (Character.getType(c2)){
	    case Character.UPPERCASE_LETTER: 
		c2 = Character.toLowerCase(c2);
		break;
	    case Character.OTHER_LETTER:
		if (MojiBunkai.isHiragana(c2)) c2 = MojiBunkai.toKatakana(c2);
		break;
	    case Character.LOWERCASE_LETTER:
	    case Character.DECIMAL_DIGIT_NUMBER:
		break;
	    case Character.MODIFIER_LETTER:
		if (c2 == '\u309d'){
		    c2 = '\u30fd';
		    break;
		} 
		if (c2 == '\u309e'){
		    c2 = '\u30fe';
		    break;
		}
		break;
	    case Character.LETTER_NUMBER:
		if (c2 == '\u3007') {
		    c2 = '0';
		    break;
		}
	    default:
		break ;
	    }
	    result = c1-c2;
	} while ((result == 0) && (--n > 0));
	return (result);
    }
}
