/*
 * This program is Copyright 1998 by Henry Cohen commercial rights are reserved.
 * The program is provided as is with no warranties of any sort including 
 * fitness for any purpose.  In no case will the author be held liable for
 * damages related to the use of this program.

 * The author hereby grants rights to use, copy, modify and create derived
 * products for individual, non-commercial purposes provided a copy of this
 * notice is included.  Any commercial use requires the written approval of 
 * the author.
 * Henry Cohen 1998.
 */

package jdic;
import java.io.*;

class KanjiDictionary extends Dictionary{

    KanjiDictionary (File dictFile, boolean makeIndex, String encoding) 
	 throws BadIndexException, IOException, FileNotFoundException, 
	     SecurityException, UnsupportedEncodingException, EOFException {

		 super(dictFile, makeIndex, encoding);
    }

    /**
     * method kstrcmp returns -, 0 or + as dict1[i1] is < = or > than dict2[i2].
     * This version distinguishes between katakana and hiragana. We need to be
     * sure that the test for equality is really not just a prefix substring.
     * So S1 does not equal S10 etc. Prefix substrings are less than the longer
     * string.
     */
     int kstrcmp (char[] dict1, int ix1,char[] dict2, int ix2, int n){
	char c1,t1,c2,t2;
	int result = 0, l1 = dict1.length, l2 = dict2.length, remaining = n;
	
scan:	
	do {
	    try {
		c1 = dict1[ix1++];
		c2 = dict2[ix2++];
	    } catch (ArrayIndexOutOfBoundsException e) {
		break;
	    }
	    
	    switch (Character.getType(c1)){
	    case Character.UPPERCASE_LETTER: 
		c1 = Character.toLowerCase(c1);
		break;
	    case Character.LETTER_NUMBER:
		if (c1 == '\u3007') {
		    c1 = '0';
		    break;
		}
	    default:
		break ;
	    }
	    switch (Character.getType(c2)){
	    case Character.UPPERCASE_LETTER: 
		c2 = Character.toLowerCase(c2);
		break;
	    case Character.LETTER_NUMBER:
		if (c2 == '\u3007') {
		    c2 = '0';
		    break;
		}
	    default:
		break ;
	    }
	    result = c1-c2;
	} while ((result == 0) && (--remaining > 0));
	if (result != 0) return (result);
	/*
	 * ASSERT remaining == 0  
	 * check to see that we really have equality and not just a prefix
	 * substring.   This method is used in two places, first it is used
	 * while creating the index to compare strings within the dictionary.
	 * In that case both dict1.length and dict2.length will be equal to each 
	 * other and both greater than n.
	 * The other use is to compare user submitted strings to dictionary entries.
	 * in this case one of the dictx.length will equal n. 
	 * The final case required for logical completeness is for both lengths
	 * to equal n.  This will not occur in this application.  If I wanted to
	 * be sure that the method was generally reusable then I would have to 
	 * check for that. 
	 */ 
	if (dict1.length == n) {
	    /*
	     * Two possibilities for dict2.length, it can be only > or == to n.
	     */
	    if (dict2.length == n) {
		return 0;
	    } else {
		c2 = dict2[ix2];
		if (MojiBunkai.isDictChar(c2)) {
		    // Prefix substring dict1 < dict2
		    return -1;
		} else {
		    return 0;
		}
	    }
	}
	if (dict2.length == n) {
	    c1 = dict1[ix1];
	    if (MojiBunkai.isDictChar(c1)) {
		// Prefix substring dict1>dict2
		return 1;
	    } else {
		return 0;
	    }
	}
	c1 = dict1[ix1];
	c2 = dict2[ix2];
	if (MojiBunkai.isDictChar(c1)) {
	    if (MojiBunkai.isDictChar(c2)) {
		return 0;  // equal up to length n. Don't care past that.
	    } else {
		return 1;
	    }
	} else {
	    if (MojiBunkai.isDictChar(c2)) {
		return -1;
	    } else {
		return 0;
	    }
	}
    }
}

