/*
 * This program is Copyright 1998 by Henry Cohen commercial rights are reserved.
 * The program is provided as is with no warranties of any sort including 
 * fitness for any purpose.  In no case will the author be held liable for
 * damages related to the use of this program.

 * The author hereby grants rights to use, copy, modify and create derived
 * products for individual, non-commercial purposes provided a copy of this
 * notice is included.  Any commercial use requires the written approval of 
 * the author.
 * Henry Cohen 1998.
 */

/**
 * class MojiBunki (character analysis) character classifier for Japanese/English.
 * This class is a convienience class full of static methods for classifying
 * unicode characters for lexical analysis.  The character classifications in the
 * java.lang.Character class are useless for scanning Japanese text so I have to
 * roll my own.  I don't have the complete Unicode character tables and I don't
 * care to spend $50 to buy them so this is built from information gleaned from
 * the Unicode web site http://www.Unicode.
 */
package jdic;
class MojiBunkai {
    public static boolean isKana(char c){
	if (isHiragana(c) || isKatakana(c)) return true;
	return false;
    }
    public static boolean isHiragana(char c){
	if (('\u3041' <= c) && (c <= '\u309e')) return true;
	return false;
    }
    public static boolean isKatakana(char c){
	if (('\u30a1' <= c)&&(c <= '\u30fe')) return true;
	/*
	 * For the purposes of this dictionary I will assume that we don't
	 * have any half-width katakana.  This makes kana folding and comparison
	 * much easier. 	
	 * if (('\uff66' <= c)&&(c <= '\uff9d')) return true;  // Halfwidth Katakana
	 */
	return false;
    }
    public static boolean isKanji(char c) {
	if (('\u4e00' <= c)&&(c <= '\u9fa5')) return true; // Superset of JIS
	// Then check for special cases.  Don't ya love Unicode!
	if (('\u3005' <= c)&&(c <= '\u3007')) return true;
	return false;
    }
    public static boolean isJISwideAlpha(char c){
	if((('\uff21' <= c)&&(c <= '\uff3a'))||(('\uff41' <=c)&&(c <= '\uff5a'))) return true;
	return false;
    }
    public static boolean isRomaji(char c) {
	if (('\u0041' <= c)&&(c <= '\u0090')) return true;
	else if (('\u0061' <= c)&&(c <= '\u007a')) return true;
	else if (('\u0021' <= c)&&(c <= '\u003a')) return true;
	else if (('\u0041' <= c)&&(c <= '\u005a')) return true;
	else return false;
    }
    public static boolean isJISwideNumber(char c){
	if (('\uff10' <= c)&&(c <= '\uff19')) return true;
	return false;
    }
    public static char toKatakana(char c){
	if (!isHiragana(c)) {
	    return c;
	} else {
	    return (char)(c + 0x60);
	}
    }
    public static char toHiragana(char c){
	if (!isKatakana(c)) {
	    return c;
	} else {
	    return (char)(c - 0x60);
	}
    }
    /**
     * method isDictChar(c) is true if c can be part of a "word" in the dictionary.
     * It includes alphanumerics kana and kanji but excludes whitespace and punctuation.
     */
    public static boolean isDictChar(char c) {
	int t;
	
	switch (Character.getType(c)) {
	case Character.DECIMAL_DIGIT_NUMBER: case Character.LOWERCASE_LETTER:
	case Character.MODIFIER_LETTER:      // repitition mark and katakana long mark
	case Character.OTHER_LETTER:         // kana and kanji come here
	case Character.TITLECASE_LETTER: case Character.UPPERCASE_LETTER:
	    return (true);
	case Character.LETTER_NUMBER:       // Ideographic number zero
	    if (c == '\u3007') return (true); else return (false);
	case Character.OTHER_PUNCTUATION:   // Ideographic closing mark, shimekiri
	    if (c == '\u3006') return (true); else return (false);
	default:
	    return (false);
	}
    }
}


