/*
 * This program is Copyright 1998 by Henry Cohen commercial rights are reserved.
 * The program is provided as is with no warranties of any sort including 
 * fitness for any purpose.  In no case will the author be held liable for
 * damages related to the use of this program.

 * The author hereby grants rights to use, copy, modify and create derived
 * products for individual, non-commercial purposes provided a copy of this
 * notice is included.  Any commercial use requires the written approval of 
 * the author.
 * Henry Cohen 1998.
 */

package jdic;

import java.awt.*;
import java.awt.event.*;
import jdic.RadTable.*;

class RadicalPanel extends KanjiPanel {
    KanjiInput parent;
    
    public RadicalPanel(String[] radList, KanjiInput parent) {
	super(radList);
	this.parent = parent;
    }
    public void kanjiSelection (String radSelection) {
	parent.addPlusStrokes(radSelection.charAt(0));
    }
    void paintGlyph(Graphics g, String glyph, int x, int y) {
	/* 
	 * Java 1.1 heuristic.  I assume that all proper kanji should fit
	 * within a cell +- 10% of any other kanji.  Actually since most if
	 * not all kanji fonts are actually monospaced this test may be too
	 * loose.  On Windoze the system prints a period for unprintable characters.
	 * the period is 1/2 the size of the kanji cell.  Alternatively if a system
	 * prints a unicode escape \uFFFF it will be much larger than a kanji cell.
	 * It's just a heuristic until I can use Java 1.2 that has a method to
	 * tell if a glyph is present in a font.
	 */
	int standardCell = this.fontMetrics.charWidth('\u5b57');
	char thisChar = glyph.charAt(0);
	int thisGlyph = this.fontMetrics.charWidth(thisChar);
	/*
	 * In Java 1.2 there is a method in the font class to determine if the
	 * font contains a glyph for a particular character.  Without such a 
	 * method we have to check all radical characters for substitutes.
	 /
	if (font.canDisplay(thisChar)) {
	*/
	/*
	     * Char not in font so ask RadTable for a substitute.
	     */
	    Substitute substitute = RadTable.radSubstitute(thisChar);
	    if (substitute != null){
		Color foreground = this.getForeground();
		Color lightBackground = this.getBackground();
		Color darkBackground = lightBackground.darker().darker();
		if (substitute.order == Substitute.LIGHT_DARK) {
		    g.setColor(lightBackground);
		    g.fillRect(x+1+(int)((cellWidth-2)*substitute.light.x1), 
			       y+1+(int)((cellHeight-2)*substitute.light.y1),
			       (int)((cellWidth-2)*substitute.light.x2)-
			       (int)((cellWidth-2)*substitute.light.x1),
			       (int)((cellHeight-2)*substitute.light.y2)-
			       (int)((cellHeight-2)*substitute.light.y1));
		    g.setColor(darkBackground);
		    g.fillRect(x+1+(int)((cellWidth-2)*substitute.dark.x1), 
			       y+1+(int)((cellHeight-2)*substitute.dark.y1),
			       (int)((cellWidth-2)*substitute.dark.x2)-
			       (int)((cellWidth-2)*substitute.dark.x1),
			       (int)((cellHeight-2)*substitute.dark.y2)-
			       (int)((cellHeight-2)*substitute.dark.y1));

		} else {
		    g.setColor(darkBackground);
		    g.fillRect(x+1+(int)((cellWidth-2)*substitute.dark.x1), 
			       y+1+(int)((cellHeight-2)*substitute.dark.y1),
			       (int)((cellWidth-2)*substitute.dark.x2)-
			       (int)((cellWidth-2)*substitute.dark.x1),
			       (int)((cellHeight-2)*substitute.dark.y2)-
			       (int)((cellHeight-2)*substitute.dark.y1));
		    g.setColor(lightBackground);
		    g.fillRect(x+1+(int)((cellWidth-2)*substitute.light.x1), 
			       y+1+(int)((cellHeight-2)*substitute.light.y1),
			       (int)((cellWidth-2)*substitute.light.x2)-
			       (int)((cellWidth-2)*substitute.light.x1),
			       (int)((cellHeight-2)*substitute.light.y2)-
			       (int)((cellHeight-2)*substitute.light.y1));
		}
		Character c = new Character(substitute.substitute);
		String s = c.toString();
		g.setColor(foreground);
		g.drawString(s,x+baseXOffset, y+baseYOffset);
	    } else {
		g.drawString(glyph, x+baseXOffset, y+baseYOffset);
	    }
// 	} else {	   
// 	    g.drawString(glyph, x+baseXOffset, y+baseYOffset);
// 	}
    }
}
